summaryrefslogtreecommitdiff
path: root/src/cairo-pdf-surface-private.h
diff options
context:
space:
mode:
authorAdrian Johnson <ajohnson@redneon.com>2017-11-09 20:52:36 +1030
committerAdrian Johnson <ajohnson@redneon.com>2017-11-09 20:52:36 +1030
commitbff47b43c4b0501c0255e9ba191904bea13ddf5c (patch)
tree2482ca1ae21973c3ac40454f07a851d3ff6e5d35 /src/cairo-pdf-surface-private.h
parentcf9a07035292f3a1a3d057cfbb9dac1447a11235 (diff)
downloadcairo-bff47b43c4b0501c0255e9ba191904bea13ddf5c.tar.gz
pdf: fix mime-unique-id unbounded recording test
PDF XObjects need to specify the bounding box. Emit unbounded surfaces when finishing as at this point the extents of all uses of the unbounded surface are known.
Diffstat (limited to 'src/cairo-pdf-surface-private.h')
-rw-r--r--src/cairo-pdf-surface-private.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/cairo-pdf-surface-private.h b/src/cairo-pdf-surface-private.h
index 75d5259c3..51be68258 100644
--- a/src/cairo-pdf-surface-private.h
+++ b/src/cairo-pdf-surface-private.h
@@ -80,8 +80,10 @@ typedef struct _cairo_pdf_source_surface_entry {
cairo_pdf_resource_t surface_res;
cairo_pdf_resource_t smask_res;
- /* Extents of the source surface. If bounded is false,
- * extents is the ink extents. */
+ /* True if surface will be emitted as an Image XObject. */
+ cairo_bool_t emit_image;
+
+ /* Extents of the source surface. */
cairo_bool_t bounded;
cairo_rectangle_int_t extents;
@@ -262,6 +264,7 @@ struct _cairo_pdf_surface {
cairo_array_t alpha_linear_functions;
cairo_array_t page_patterns;
cairo_array_t page_surfaces;
+ cairo_array_t doc_surfaces;
cairo_hash_table_t *all_surfaces;
cairo_array_t smask_groups;
cairo_array_t knockout_group;